/* eslint-disable import/no-extraneous-dependencies */
import React, { useState } from 'react';
import { QrPlace } from '~/business-logic/core/places/common/entity/placeEntity';
import Modal from '~/driven/utils/components/modal/Modal';
import { icons } from '~/driven/utils/constants/assertUrls';
import { QRCodeCanvas } from 'qrcode.react';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import { ITableRowInfra } from '../../../infra/protocols';

interface IRowItemProp {
  title: string | null | QrPlace;
  hasCheckbox: boolean;
  isSelected: boolean;
  rowData: ITableRowInfra['rowData'];
}

function QrCodeReader(props: { QrCodeData: QrPlace; rowData: ITableRowInfra['rowData'] }) {
  const { QrCodeData, rowData } = props;
  const placeType = rowData.rowItemsTitle[1];
  const placeTitle = rowData.rowItemsTitle[0];
  const isOneTime = !QrCodeData.oneTime ? staticMessages.global.multipleTimes : staticMessages.global.oneTime;

  const message = `${placeType} ${placeTitle} ${staticMessages.global.and} ${staticMessages.global.canUseFor} ${isOneTime}`;
  return <QRCodeCanvas id='qrCode' value={message} size={150} bgColor='#fff' level='H' />;
}

function QrCodeButton(props: { QrCodeData: QrPlace; rowData: ITableRowInfra['rowData'] }) {
  const { QrCodeData, rowData } = props;
  const [isShowModal, setIsShowModal] = useState(false);

  if (!QrCodeData) return null;
  return (
    <>
      {isShowModal && (
        <Modal onCloseCallback={() => setIsShowModal(false)}>
          <QrCodeReader rowData={rowData} QrCodeData={QrCodeData} />
        </Modal>
      )}
      <button
        onClick={(e) => {
          e.stopPropagation();
          setIsShowModal(true);
        }}
        className='w-full h-full mx-auto flex justify-center items-center'
      >
        <img className='w-6 h-6' src={icons.qrcode} alt='qrcode' />
      </button>
    </>
  );
}

export default function RowItem(props: IRowItemProp) {
  const { title, hasCheckbox, isSelected, rowData } = props;
  return (
    <td className={`px-1 py-2 ${isSelected ? 'bg-primary-100' : ''}`}>
      <div className='w-full flex'>
        {hasCheckbox && (
          <span
            className={`checkmak-container flex justify-center items-center mr-2 transition-all ${
              isSelected ? 'opacity-100' : 'opacity-0'
            }`}
          >
            <span className={`${isSelected ? 'visible' : 'hidden'} transition-all`}>&#10003;</span>
          </span>
        )}
        {typeof title === 'string' ? title : <QrCodeButton rowData={rowData} QrCodeData={title as QrPlace} />}
      </div>
    </td>
  );
}
